From a7f894980e77c0a40b0d9c61779337c2c34034c2 Mon Sep 17 00:00:00 2001
From: Ruslan Migirov <trapi78@gmail.com>
Date: Wed, 22 Nov 2023 20:36:30 +0200
Subject: [PATCH] Fix pointer-to-integer casting precision loss in gr-osmosdr

Changed the casting of pointers to `long int` to `reinterpret_cast<std::intptr_t>`
in `source_impl.cc` and `sink_impl.cc`. This resolves the issue of precision
loss when compiling on 64-bit systems, where the size of pointers is 64 bits
and `long int` is typically 32 bits. Using `std::intptr_t` ensures safe
and portable casting across different platforms.
Additionally this fixes build in MSYS2 MinGW64 environment.
---
 lib/sink_impl.cc   | 4 ++--
 lib/source_impl.cc | 4 ++--
 2 files changed, 4 insertions(+), 4 deletions(-)

diff --git a/lib/sink_impl.cc b/lib/sink_impl.cc
index d38bd01..68ad7f3 100644
--- a/lib/sink_impl.cc
+++ b/lib/sink_impl.cc
@@ -232,13 +232,13 @@ sink_impl::sink_impl( const std::string &args )
     }
 #endif
 
-    if ( iface != NULL && long(block.get()) != 0 ) {
+    if (iface != NULL && reinterpret_cast<std::intptr_t>(block.get()) != 0) {
       _devs.push_back( iface );
 
       for (size_t i = 0; i < iface->get_num_channels(); i++) {
         connect(self(), channel++, block, i);
       }
-    } else if ( (iface != NULL) || (long(block.get()) != 0) )
+    } else if ((iface != NULL) || (reinterpret_cast<std::intptr_t>(block.get()) != 0))
       throw std::runtime_error("Either iface or block are NULL.");
 
   }
diff --git a/lib/source_impl.cc b/lib/source_impl.cc
index c03c43d..3d2a266 100644
--- a/lib/source_impl.cc
+++ b/lib/source_impl.cc
@@ -396,7 +396,7 @@ source_impl::source_impl( const std::string &args )
     }
 #endif
 
-    if ( iface != NULL && long(block.get()) != 0 ) {
+    if (iface != NULL && reinterpret_cast<std::intptr_t>(block.get()) != 0 ) {
       _devs.push_back( iface );
 
       for (size_t i = 0; i < iface->get_num_channels(); i++) {
@@ -416,7 +416,7 @@ source_impl::source_impl( const std::string &args )
         connect(block, i, self(), channel++);
 #endif
       }
-    } else if ( (iface != NULL) || (long(block.get()) != 0) )
+    } else if ((iface != NULL) || (reinterpret_cast<std::intptr_t>(block.get()) != 0))
       throw std::runtime_error("Either iface or block are NULL.");
 
   }
-- 
2.41.0

